/*	get:	/edx/src/s.vtab.h 90/01/18 16:51:12
*	delta:	6.2 90/01/18 16:49:26
*	module:	vtab.h
*
*	Volume control table
*
*	Translates edx volumes into path names specified by users.
*
*	Written to the file edxvtab.sys to be compatible with H&A PXS/PC vecb
*	vhead follows the 256 byte efh control header
*	vent(ries) follow the headers up the max specified in the header
*	maintained by initdsk utility...
*
*	Update History
*	--------------
*	03/08/85 jbw - original
*	11/29/88  gs	UNIX conversion
*/

enum { MAXVTES = 128, VTHSIZE = 64 };	/* maximum volume table entries */

typedef struct s_vtent {		/* volume table entry */
    BYTE	volume[6];		/* volume name (EBCDIC, space filled) */
    char	path[58];		/* path name (ASCII, null term) */
} VTENT;

/**
* Volume table header only the first 64 bytes are written to the file.
**/
typedef struct s_vthead {	/* volume table header */
    WORD	count;		/* number of volume entries */
    WORD	max_ent;	/* max number of entries */
    BYTE	nucfile[8];	/* nucleus file name (EBCDIC) */
    BYTE	def_vol[6];	/* default volume (EBCDIC)*/
	/* above fields stored in file */
    char	dvpath[64];	/* default volume path name (ASCII) */
    VTENT	vtes[1];	/* volume table (max_ent entries) */
} VTHEAD;

#ifndef __cplusplus
    /* size of volume table header */
    /* allocated size of volume entry table */
#define VTESIZE(h)	(sizeof(VTENT)*h->max_ent)

#define VTABFILE	"edxvtab.sys"	/* volume table file name */
    /* nucvtab.c */
#ifndef UTILITY
extern VTHEAD *vthead;
#endif
void readvtab(const char *);	/* read nucleus vtab and convert volume
				   names to EBCDIC.  edxnuc insists. */

/* build ascii unix pathnames from EDX name and volume in ascii */
int bldpathnx(const char [8], const char [6], char *);
int bldpath(const char [8], const char [6], char *);

    /* vtab.c */
VTHEAD *get_vtab_by_name(const char *);

    /* edxvtab.c */
/* build ascii unix path from name and volume in EDX memory (ebcdic) */
char *edxpath(char *, WORD, ADDR, ADDR);
char *edxpathnx(char *, WORD, ADDR, ADDR);
char *edxsysfile(char *, const char *);
#endif
